==> haskell-code-page-0.1.3-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-code-page.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: code-page
version: 0.1.3
id: code-page-0.1.3-Fxfj8KlZt5M4CQMDwRDd5i
key: code-page-0.1.3-Fxfj8KlZt5M4CQMDwRDd5i
license: BSD3
copyright: (C) 2016-2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
stability: Provisional
homepage: https://github.com/RyanGlScott/code-page
synopsis: Windows code page library for Haskell
description:
    This library provides two modules:
    .
    * "System.IO.CodePage": a cross-platform module that exports
    functions which adjust code pages on Windows, and do nothing
    on other operating systems.
    .
    * "System.Win32.CodePage": On Windows, this exports functions
    for getting, setting, and analyzing code pages. On other
    operating systems, this module exports nothing.
category: System
author: Ryan Scott
exposed: True
exposed-modules:
    System.IO.CodePage System.Win32.CodePage
abi: 3f265265909ec34950b8bf22f5a278f2
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/code-page-0.1.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/code-page-0.1.3
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/code-page-0.1.3
hs-libraries: HScode-page-0.1.3-Fxfj8KlZt5M4CQMDwRDd5i
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-code-page/html/code-page.haddock
haddock-html: /usr/share/doc/haskell-code-page/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-code-page-0.1.3-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-code-page.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: code-page
version: 0.1.3
id: code-page-0.1.3-Lb49vTg78IDCCaaNT9XtlB
key: code-page-0.1.3-Lb49vTg78IDCCaaNT9XtlB
license: BSD3
copyright: (C) 2016-2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
stability: Provisional
homepage: https://github.com/RyanGlScott/code-page
synopsis: Windows code page library for Haskell
description:
    This library provides two modules:
    .
    * "System.IO.CodePage": a cross-platform module that exports
    functions which adjust code pages on Windows, and do nothing
    on other operating systems.
    .
    * "System.Win32.CodePage": On Windows, this exports functions
    for getting, setting, and analyzing code pages. On other
    operating systems, this module exports nothing.
category: System
author: Ryan Scott
exposed: True
indefinite: False
exposed-modules:
    System.IO.CodePage System.Win32.CodePage
abi: 50f3be7e05c03942f950eb5f5ca7566b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/code-page-0.1.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/code-page-0.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/code-page-0.1.3
hs-libraries: HScode-page-0.1.3-Lb49vTg78IDCCaaNT9XtlB
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
haddock-interfaces: /usr/share/doc/haskell-code-page/html/code-page.haddock
haddock-html: /usr/share/doc/haskell-code-page/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
